#
# spec file for package perl-File-FcntlLock
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-File-FcntlLock
Version:        0.22
Release:        5.5
%define cpan_name File-FcntlLock
Summary:        File locking with L<fcntl(2)>
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/File-FcntlLock/
Source:         http://www.cpan.org/authors/id/J/JT/JTT/%{cpan_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
File locking in Perl is usually done using the 'flock' function.
Unfortunately, this only allows locks on whole files and is often
implemented in terms of the the flock(2) manpage system function which has
some shortcomings (especially concerning locks on remotely mounted file
systems) and slightly different behaviour than the fcntl(2) manpage.

Using this module file locking via the fcntl(2) manpage can be done
(obviously, this restricts the use of the module to systems that have a the
fcntl(2) manpage system call). Before a file (or parts of a file) can be
locked, an object simulating a flock structure, containing information in a
binary format to be passed to the fcntl(2) manpage for locking requests,
must be created and its properties set. Afterwards, by calling the the
lock() manpage method a lock can be set and removed or it can be determined
if and which process currently holds the lock.

File::FcntlLock (or its alias File::FcntlLock::XS) uses a shared library,
build during installation, to call the the fcntl(2) manpage system function
directly. If this is unsuitable there are two alternatives,
File::FcntlLock::Pure and File::FcntlLock::Inline. Both call the Perl
'fcntl' function instead and use Perl code to assemble and disassemble the
structure. For this at some time the (system-dependent) binary layout of
the flock structure must have been determined via a program written in C.
The difference between File::FcntlLock::Pure and File::FcntlLock::Inline is
that for the former this happened when the package is installed while for
the latter it is done each time the package is loaded (e.g., with 'use').
Thus, for File::FcntlLock::Inline to work a C compiler must be available.
There are some minor differences in the functionality and the behaviour on
passing the method for locking invalid arguments to be described below.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.22
  see /usr/share/doc/packages/perl-File-FcntlLock/Changes
  0.22  Thu July 31 2014
  - Exports still didn't work from the XS, Pure and Inline modules,
  hopefully fixed.
  0.21  Thu July 31 2014
  - Missing @EXPORT of constants fixed with patch supplied by
  Raphaël Hertzog <hertzog@debian.org> (thank you;-)
* Fri Jul 25 2014 coolo@suse.com
- updated to 0.20
  - Problem on GNU Hurd hopefully fixed and some cosmetic changes.
  0.19  Tue May 27 2014
  - Builds failed on 32-bit systems due to missing CFLAGS derived
    from the Perl installation.
  0.18  Mon May 26 2014
  - CPAN didn't find the version number in FcntlLock.pm which
    was derived from that of Core.pm:-(
  0.17  Mon May 26 2014
  - CPAN testing showed that there are 32-bit systems where the
    off_t member of the flock struct is a 64-bit integer but Perl
    doesn't support the 'q' format for pack() and unpack(). On these
    systems there seem to be no good way of assembling a flock
    structure useing "pure Perl" and thus the File::FcntlLock::Pure
    and File::FcntlLock::Inline modules won't get installed.
  0.16  Sun May 25 2014
  - Missing file in 0.15, Pure.pm, in MANIFEST added.
  0.15  Thu May 20 2014
  - Module rewritten as three modules, one working
    exactly as before, and two new ones that instead of
    being XS-based use Perl code. For the first one the
    Perl code for packing/unpacking the C flock struct is
    generated when 'perl Makefile.PL' is run. For the other
    a C program is created, compiled and run each time the
    module gets loaded. This is in response to some concerns
    the Debian dpkg package managers (who use the module) had
    for certain circumstances when new Perl versions need to
    be installed (as far as I understand;-)
* Tue Sep 25 2012 frank.lichtenheld@sophos.com
- initial packaging based on cpanspec
  * made backwards compatible to SLE 11 SP2
